@@ -149,3 +149,21 @@ def read_and_preprocess_txrm(projections_file, downsample_factor=1, angular_fact
         projections[i, :, :] = np.squeeze(projection)
 
     return projections
+
+
+def read_single_projection(projections_file, downsample_factor=1, angular_factor=1, do_truncation_correction=True,
+                             extension_fraction=0.1, datatype=np.float32):
+    metadata = read_metadata(str(projections_file))
+    reference = metadata['reference']
+
+    for projection in read_txrm_iterable(str(projections_file)):
+        projection = np.expand_dims(projection, 0)
+        projection = divide_by_reference(projection, reference)
+        if downsample_factor != 1 or angular_factor != 1:
+            projection = downsample(projection, downsample_factor, angular_factor)
+        projection = negative_logarithm(projection)
+        if do_truncation_correction:
+            projection = truncation_correction(projection, extension_fraction=extension_fraction)
+        break
+
+    return projection
